cheesecake.logger.MultipleProducer

Package cheesecake :: Module logger :: Class MultipleProducer |
[hide private]
[frames] | no frames]

## Class MultipleProducer
source code

    object --+
             |
      Producer --+
                 |
                MultipleProducer

Nested Classes | [hide private]
Inherited from `Producer`: `Message`

Instance Methods | [hide private]
| __call__(self, *args, **kwargs)
| _getconsumer(self, keywords)
Inherited from `Producer`: `__getattr__`, `__init__`, `__repr__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `Producer`: `keywords2consumer` Inherited from `object`: `__class__`

Method Details | [hide private]

### __call__(self, *args, **kwargs) (Call operator) | source code
Overrides: Producer.__call__

### _getconsumer(self, keywords) | source code
Overrides: Producer._getconsumer